<?php

/*
 * LMS version 1.3.1 Maybourne
 *
 *  (C) Copyright 2001-2004 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: nodeset.php,v 1.17 2004/02/21 19:38:17 lukasz Exp $
 */

if($LMS->UserExists($_GET['ownerid']))
{
	$LMS->NodeSetU($_GET['ownerid'], $_GET['access']);
	$backid = $_GET['ownerid'];
}

if($LMS->NodeExists($_GET['id']))
{
	$LMS->NodeSet($_GET['id']);
	$backid = $_GET['id'];
}

if(isset($_GET['netdev']))
	if($LMS->NetDevExists($_GET['netdev']))
	{
		$LMS->IPSetU($_GET['netdev'], $_GET['access']);
		$backid = $_GET['netdev'];
	}

header("Location: ?".$_SESSION['backto']."#".$backid);

?>
